@@ -36,7 +36,7 @@ import org.uberfire.java.nio.file.FileSystem;
 import org.uberfire.java.nio.file.Path;
 
 import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.*;
 
 @RunWith(org.jboss.byteman.contrib.bmunit.BMUnitRunner.class)
@@ -62,6 +62,7 @@ public class BatchIndexConcurrencyTest extends BaseIndexTest {
             metaIndexEngine = spy(config.getIndexEngine());
 
             ioService = new IOServiceIndexedImpl(metaIndexEngine,
+                                                 Executors.newCachedThreadPool(new DescriptiveThreadFactory()),
                                                  Executors.newCachedThreadPool(new DescriptiveThreadFactory()),
                                                  indexersFactory(),
                                                  indexerDispatcherFactory(config.getIndexEngine()),
