@@ -58,6 +58,7 @@ public class LuceneFullTextSearchIndexTest extends BaseIndexTest {
                     .build();
 
             ioService = new IOServiceIndexedImpl(config.getIndexEngine(),
+                                                 Executors.newCachedThreadPool(new DescriptiveThreadFactory()),
                                                  Executors.newCachedThreadPool(new DescriptiveThreadFactory()),
                                                  indexersFactory(),
                                                  indexerDispatcherFactory(config.getIndexEngine()),
@@ -83,7 +84,7 @@ public class LuceneFullTextSearchIndexTest extends BaseIndexTest {
 
         waitForCountDown(10000);
 
-        final String index = toKCluster(path1.getFileSystem()).getClusterId();
+        final String index = toKCluster(path1).getClusterId();
 
         {
 
