@@ -40,7 +40,7 @@ import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.file.Path;
 
@@ -148,8 +148,8 @@ public class ModuleMavenRepositoryResolverImplTest {
                                      "http://repository.jboss.org/nexus/content/groups/public/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
-            assertContainsRepository("jboss-origin-repository-group",
-                                     "https://origin-repository.jboss.org/nexus/content/groups/ea/",
+            assertContainsRepository("jboss-snapshots-repository-group",
+                                     "https://repository.jboss.org/nexus/content/repositories/snapshots/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
             assertContainsRepository("jboss-public-repository-group",
@@ -213,8 +213,8 @@ public class ModuleMavenRepositoryResolverImplTest {
                                      "http://repository.jboss.org/nexus/content/groups/public/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
-            assertContainsRepository("jboss-origin-repository-group",
-                                     "https://origin-repository.jboss.org/nexus/content/groups/ea/",
+            assertContainsRepository("jboss-snapshots-repository-group",
+                                     "https://repository.jboss.org/nexus/content/repositories/snapshots/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
             assertContainsRepository("jboss-public-repository-group",
@@ -282,8 +282,8 @@ public class ModuleMavenRepositoryResolverImplTest {
                                      "http://repository.jboss.org/nexus/content/groups/public/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
-            assertContainsRepository("jboss-origin-repository-group",
-                                     "https://origin-repository.jboss.org/nexus/content/groups/ea/",
+            assertContainsRepository("jboss-snapshots-repository-group",
+                                     "https://repository.jboss.org/nexus/content/repositories/snapshots/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
             assertContainsRepository("jboss-public-repository-group",
@@ -351,8 +351,8 @@ public class ModuleMavenRepositoryResolverImplTest {
                                      "http://repository.jboss.org/nexus/content/groups/public/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
-            assertContainsRepository("jboss-origin-repository-group",
-                                     "https://origin-repository.jboss.org/nexus/content/groups/ea/",
+            assertContainsRepository("jboss-snapshots-repository-group",
+                                     "https://repository.jboss.org/nexus/content/repositories/snapshots/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
             assertContainsRepository("jboss-public-repository-group",
@@ -416,8 +416,8 @@ public class ModuleMavenRepositoryResolverImplTest {
                                      "http://repository.jboss.org/nexus/content/groups/public/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
-            assertContainsRepository("jboss-origin-repository-group",
-                                     "https://origin-repository.jboss.org/nexus/content/groups/ea/",
+            assertContainsRepository("jboss-snapshots-repository-group",
+                                     "https://repository.jboss.org/nexus/content/repositories/snapshots/",
                                      MavenRepositorySource.SETTINGS,
                                      metadata);
             assertContainsRepository("jboss-public-repository-group",
@@ -976,10 +976,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                 "  <version>0.0.15</version>\n" +
                 "</project>";
 
-        when(module.getPomXMLPath()).thenReturn(pomXmlPath);
-        when(pomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-        when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
         final String oldSettingsXmlPath = System.getProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY);
 
         try {
@@ -1012,10 +1008,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                     "  <version>0.0.16</version>\n" +
                     "</project>";
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
 
@@ -1066,10 +1058,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                     "  </distributionManagement>\n" +
                     "</project>";
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
 
@@ -1129,10 +1117,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                     "  </distributionManagement>\n" +
                     "</project>";
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
 
@@ -1196,10 +1180,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                     "  </distributionManagement>\n" +
                     "</project>";
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
 
@@ -1275,7 +1255,7 @@ public class ModuleMavenRepositoryResolverImplTest {
     @Test
     public void testGetRepositoriesResolvingArtifact_Disabled2() {
         final Module module = mock(Module.class);
-        doReturn("file://master@a/a%20b").when(module).getIdentifier();
+        doReturn("file://main@a/a%20b").when(module).getIdentifier();
         doCallRealMethod().when(module).getEncodedIdentifier();
         final org.uberfire.backend.vfs.Path vfsPomXmlPath = mock(org.uberfire.backend.vfs.Path.class);
         final String oldSettingsXmlPath = System.getProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY);
@@ -1294,10 +1274,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                                     "test",
                                     "0.0.21");
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
             doReturn(true).when(gavPreferences).isConflictingGAVCheckDisabled();
@@ -1338,10 +1314,6 @@ public class ModuleMavenRepositoryResolverImplTest {
                     "  <version>0.0.22</version>\n" +
                     "</project>";
 
-            when(module.getPomXMLPath()).thenReturn(vfsPomXmlPath);
-            when(vfsPomXmlPath.toURI()).thenReturn("file://p0/pom.xml");
-            when(ioService.readAllString(any(Path.class))).thenReturn(pomXml);
-
             System.setProperty(MavenSettings.CUSTOM_SETTINGS_PROPERTY,
                                settingsXmlPath.toString());
             doReturn(true).when(gavPreferences).isConflictingGAVCheckDisabled();
