@@ -31,7 +31,7 @@ import javax.inject.Named;
 import org.guvnor.common.services.backend.exceptions.ExceptionUtilities;
 import org.guvnor.common.services.project.events.RepositoryContributorsUpdatedEvent;
 import org.guvnor.structure.backend.backcompat.BackwardCompatibleUtil;
-import org.guvnor.structure.contributors.Contributor;
+import org.uberfire.security.Contributor;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.organizationalunit.config.RepositoryConfiguration;
@@ -50,6 +50,7 @@ import org.guvnor.structure.repositories.RepositoryRemovedEvent;
 import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.server.config.ConfigurationFactory;
 import org.guvnor.structure.server.config.ConfigurationService;
+import org.guvnor.structure.server.config.PasswordService;
 import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.jboss.errai.bus.server.annotations.Service;
 import org.jboss.errai.security.shared.api.identity.User;
@@ -66,6 +67,9 @@ import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.spaces.Space;
 import org.uberfire.spaces.SpacesAPI;
 
+import static org.guvnor.structure.backend.InputEscapeUtils.escapeContributorsNames;
+import static org.guvnor.structure.repositories.EnvironmentParameters.CRYPT_PREFIX;
+import static org.guvnor.structure.repositories.EnvironmentParameters.SECURE_PREFIX;
 import static org.guvnor.structure.repositories.EnvironmentParameters.SCHEME;
 import static org.uberfire.backend.server.util.Paths.convert;
 
@@ -107,6 +111,8 @@ public class RepositoryServiceImpl implements RepositoryService {
 
     private Event<RepositoryContributorsUpdatedEvent> repositoryContributorsUpdatedEvent;
 
+    private PasswordService secureService;
+
     public RepositoryServiceImpl() {
     }
 
@@ -125,7 +131,8 @@ public class RepositoryServiceImpl implements RepositoryService {
                                  final User user,
                                  final SpacesAPI spacesAPI,
                                  final SpaceConfigStorageRegistry spaceConfigStorage,
-                                 final Event<RepositoryContributorsUpdatedEvent> repositoryContributorsUpdatedEvent) {
+                                 final Event<RepositoryContributorsUpdatedEvent> repositoryContributorsUpdatedEvent,
+                                 final PasswordService secureService) {
         this.ioService = ioService;
         this.metadataStore = metadataStore;
         this.configurationService = configurationService;
@@ -141,6 +148,7 @@ public class RepositoryServiceImpl implements RepositoryService {
         this.spacesAPI = spacesAPI;
         this.spaceConfigStorage = spaceConfigStorage;
         this.repositoryContributorsUpdatedEvent = repositoryContributorsUpdatedEvent;
+        this.secureService = secureService;
     }
 
     @Override
@@ -532,7 +540,7 @@ public class RepositoryServiceImpl implements RepositoryService {
 
         thisRepositoryConfig.ifPresent(config -> {
             config.getConfiguration().add("contributors",
-                                          contributors);
+                                          escapeContributorsNames(contributors));
             this.saveRepositoryConfig(repository.getSpace().getName(),
                                       config);
             repositoryContributorsUpdatedEvent.fire(new RepositoryContributorsUpdatedEvent(getRepositoryFromSpace(repository.getSpace(),
@@ -603,10 +611,13 @@ public class RepositoryServiceImpl implements RepositoryService {
 
         String key = configuration.getName();
         if (configuration.isSecuredConfigurationItem()) {
-            key = "secure:" + key;
+            String subKey = key.substring(CRYPT_PREFIX.length());
+            String encrypted = secureService.encrypt(configuration.getValue().toString());
+            String newKey = SECURE_PREFIX + subKey;
+            repositoryConfiguration.add(newKey, encrypted);
+        } else {
+            repositoryConfiguration.add(key, configuration.getValue());
         }
-        repositoryConfiguration.add(key,
-                                    configuration.getValue());
     }
 
     public class NoActiveSpaceInTheContext extends RuntimeException {
